#!/bin/bash

#   diss.sh - This is the main menu script, from this script the others
#   executed.
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

clear
source /etc/diss/diss.conf

systemmenu () {
	while true ; do
		source /etc/diss/diss.conf
		SYSMENU=`whiptail --nocancel --title "DISS v.${VERSION}" --menu "System Management" 0 0 2 \
		${BASE} " - ${BASESTATE} - Base install" \
		${BASEWEB} " - ${WEBSTATE} - Install the LAMP server (Apache/Mysql/Php/ftp/...)" \
		${BASEMAIL} " - ${MAILSTATE} - Install Postfix/Mysql/Squirrelmail/..." \
		install_backup.sh " - ${BACKUPSTATE} - Install a backup script" \
		install_firewall.sh " - ${FIREWALLSTATE} - Install firewall" \
		reconfigure_firewall.sh " - Open or close ports on the firewall" \
		"Main Menu" " - Go back to the main menu" \
		"Quit" " - Quit DISS" 3>&2 2>&1 >&3`

		if [ "${SYSMENU}" == "Quit" ]; then
		echo "Thanks for using DISS"
			exit
		elif [ "${SYSMENU}" == "Main Menu" ]; then
			break
		fi
		bash ${SCRIPTS}/${SYSMENU}
	done
}

usermenu () {
	while true ; do
		source /etc/diss/diss.conf
		USERMENU=`whiptail --nocancel --title "DISS v.${VERSION}" --menu "User Management" 0 0 2 \
		add_client.sh " - Script for adding clients and/or websites" \
		add_database.sh " - Add a database for a client" \
		remove_client.sh " - Remove client, websites or database" \
		"Main Menu" " - Go back to the main menu" \
		"Quit"    " - Quit DISS" 3>&2 2>&1 >&3`
		if [ "${USERMENU}" == "Quit" ]; then
        		echo "Thanks for using DISS"
		exit
		elif [ "${USERMENU}" == "Main Menu" ]; then
			break
		fi
		bash ${SCRIPTS}/${USERMENU}
	done
}

mainmenu () {
	while true ; do
		source /etc/diss/diss.conf
		MAINMENU=`whiptail --nocancel --title "DISS v.${VERSION}" --menu "Please choose something to do" 0 0 2 \
		"System Management" " - Install and/or configure server software" \
		"User Management" " - Add/remove users/websites/databases.. ." \
		"Quit"	" - Quit DISS" 3>&2 2>&1 >&3`

		if [ "${MAINMENU}" == "Quit" ]; then
			echo "Thanks for using DISS"
			break
		elif [ "${MAINMENU}" == "System Management" ]; then
			systemmenu
		elif [ "${MAINMENU}" == "User Management" ]; then
			usermenu
		fi
	done
}

# show welcome message
if [ "${BASESTATE}" != "done" ]; then
	whiptail --title DISS --msgbox "DISS v.${VERSION}

Welcome to DISS - Debian Install Server Scripts..

The diss system has not yet been setup... .. .
You will be directed to the \"System Management\"
menu so you can start by installing some software." 0 0
	systemmenu
elif [ "${WEBSTATE}" != "done" ]; then
	whiptail --title DISS --msgbox "DISS v.${VERSION}

You have not yet installed the LAMP (web server) part of DISS.
You should do that maybe .. . : ]" 0 0
	systemmenu
fi

# in all other cases go with the main menu
mainmenu

exit
