#!/bin/bash

#   add_client.sh - asks questions about new client and/or website and then calls
#   the other scripts accordingly to actually do the stuff
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.


source /etc/diss/diss.conf
source ${SCRIPTS}/functions.sh
clear

# test if install_base has been done, if not show a message
THISSCRIPT=add_client.sh
DEPENDSTATE=${WEBSTATE}
DEPENDSON="install_lamp"
dependsOn

# this variable tells the add_database.sh script that it has
# been called from add_client.sh script
ADDCLIENT=1
echo "

################################
#			       #
#  add client and/or  website  #
#			       #
################################

this script will add a user to DISS (if client is new)
and setup a webspace, this means :

- *nix account (for FTP  (bin/false))
- create web directories for website
- create admin pages (for viewing stats and using phpmyadmin) with subdomain
- protect admin subdomain with htpasswd
- optional: create a database

"
echo -n "1. Add new client
2. Add webspace for an existing client
pick: "
while read NEWCLIENT; do
	if [ "${NEWCLIENT}" == "1" ] || [ "${NEWCLIENT}" == "2" ]; then
		break
	else
		echo -n "Bad answer please try again: "
	fi
done

if [ "${NEWCLIENT}" == "1" ]; then
	## get username for new client
	getInpute "Enter user/client login:" user
	CLIENT="${ANSWER}"
else
	pickAclient
fi

getInpute "Enter domain/site name (ex domain.tld):" domain
DOMAIN="${ANSWER}"
testDomain ${DOMAIN}

echo -n "Alias sub domain or alias (e.g. www.domain.tld or otherdomain.tld) OPTIONAL: "
read ALIAS
test ${ALIAS} || ALIAS="--None--"
if [ "${ALIAS}" != "--None--" ]; then
	testDomain ${ALIAS}
fi

# test if the user is new to DISS
# NEW:  1 = new client; else client exists
test -d /home/www/html/${CLIENT} || NEW=1
if [ "$NEW" = "1" ]; then
      echo "
this is a new client/user, therefore we need to create a private
webspace for the client/user to administrer some stuff.
for this we shall add a subdomain
"
	getInpute "Subdomain (for http://private.${DOMAIN} enter \"private\"):" domain
	NIMDA="${ANSWER}"
	testDomain ${NIMDA}

	getInpute "Password for ${CLIENT} (will be used for FTP, MySQL and web http://${NIMDA}.${DOMAIN}):" pw
	CLIENTPASS="${ANSWER}"
fi

echo "

###############################
#			      #
#	confirmation	      #
#			      #
###############################

 user: ${CLIENT}
 site: ${DOMAIN}
 alias: ${ALIAS}
 password : ${CLIENTPASS}"

# test if the user already exists on the system
egrep "^${CLIENT}" /etc/passwd >/dev/null
        if [ $? -eq 0 ]; then
                echo "
 => the user ${CLIENT} exists on this system,
 we shall not recreate it NOR modify
 the system password for this account."
                CREATEUSER=0
        else
                echo " => the user ${CLIENT} does not exist .. . . .. YET :]"
                CREATEUSER=1
fi

# confirm before actually doing anything
confirmORdie

# check the value of $NEW to see if we should create the account now
# otherwise we should load the clients conf
if [ "${NEW}" = "1" ]; then
        source /usr/local/${SOFTNAME}/scripts/create_nimda.sh
else
        echo "Loading client's configuration"
        source /etc/${SOFTNAME}/clients/${CLIENT}.conf
fi

# now we can actually create/configure the webspace/website
source /usr/local/${SOFTNAME}/scripts/create_webspace.sh

if [ "${ALIAS}" = "--None--" ] ; then
	NEWDOMAIN="${DOMAIN}"
else
	NEWDOMAIN="${DOMAIN} ${ALIAS}"
fi

# copy config just in case server crashes in between
cp /etc/${SOFTNAME}/clients/${CLIENT}.conf /etc/${SOFTNAME}/clients/${CLIENT}.conf.tmp.bkp
# remove old config
height=${#CLIENTDOMAIN[@]}
for i in $(seq 0 $height);
	do
	if [ -n "${CLIENTDOMAIN[$i]}" ]; then
	sed -i "/CLIENTDOMAIN\[$i\]=\"${CLIENTDOMAIN[$i]}\"/ d" /etc/${SOFTNAME}/clients/${CLIENT}.conf
	fi
done
# write new config
CLIENTDOMAIN=( "${CLIENTDOMAIN[@]}" "${NEWDOMAIN}" )
height=${#CLIENTDOMAIN[@]}
for i in $(seq 0 $height);
	do
	if [ -n "${CLIENTDOMAIN[$i]}" ]; then
	echo "CLIENTDOMAIN[$i]=\"${CLIENTDOMAIN[$i]}\"" >> /etc/${SOFTNAME}/clients/${CLIENT}.conf
	fi
done
rm /etc/${SOFTNAME}/clients/${CLIENT}.conf.tmp.bkp

echo "
Just in case let's test the apache configuration
with apache2ctl configtest:
"
echo " `apache2ctl configtest`"
echo "
If it says 'Syntax OK' then press ENTER to reload apache,
otherwise. ... .  correct errors and then
manually run \"apache2ctl graceful\" (or correct the errors
from another terminal)

Press enter to continue =>>"
read

apache2ctl graceful

echo -n "
Need we add a database for ${CLIENT} ? y/N: "
read MYSQL

if [ "${MYSQL}" = "y" ] || [ "${MYSQL}" = "Y" ]; then
	source /usr/local/${SOFTNAME}/scripts/add_database.sh
fi

echo "

#################################

   Information for ${CLIENT}

#################################

WEB/FTP
- Client's username (FTP, MySQL and htaccess): ${CLIENT}
- Password: ${CLIENTPASS}
- Configured website: ${DOMAIN}
- Absolute path: /home/www/html/${CLIENT}/${DOMAIN}
- The FTP account should land directly in /home/www/html/${CLIENT}/

MySQL/PhpMyadmin
- Database: ${SQLBASE}

DNS stuff
- Server's IP is: ${IP}

- A simple DNS configuration should ressemble (depends on how you manage your DNS):
        ${DOMAIN}  A  ${IP}"
if [ "${ALIAS}" != "--None--" ]; then
        echo "	${ALIAS}  A  ${IP}"
        fi
if [ "${NEW}" = "1" ]; then
        echo "	${NIMDA}.${DOMAIN}  A  ${IP}"
        fi

echo "
- DNS (Bind) configuration should look something like:
        ${DOMAIN} 3600 IN A ${IP}"

if [ "${ALIAS}" != "--None--" ]; then
        echo "	${ALIAS}  3600 IN A  ${IP}"
        fi
if [ "${NEW}" = "1" ]; then
        echo "	${NIMDA}.${DOMAIN}  3600 IN A  ${IP}"
        fi

echo "
Administration and misc:
- To manage and view PhpMyadmin and Awstats:"
if [ "${NEW}" = "1" ]; then
        echo "	http://${NIMDA}.${DOMAIN}"
	else
	echo "	http://${CLIENTNIMDAURL}"
	fi
echo "	User: ${CLIENT}
        Password: ${CLIENTPASS}

----------------------------------------------

Press enter to go back to DISS menu"

read
exit
