#!/bin/bash

#   install_backup.sh - configure a backup script
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

clear
source /etc/diss/diss.conf
source ${SCRIPTS}/functions.sh

THISSCRIPT=install_backup.sh
THISSTATE=${BACKUPSTATE}
installStatus

# test if install_base has been done, if not show a message
DEPENDSTATE=${BASESTATE}
DEPENDSON="install_base"
dependsOn

clear
echo "

########################################################

This script will create a backup script for your system.
for this you can use a combination of:

- local backup: will be used in all cases (or not?)
- ftp (optional) : requires a remote ftp server account

FTP option: If you need to delete your previous backup from
the FTP server you can create a file containing the
correct commands for that in:
 \"/etc/diss/ftp_pre_backup_commands\"

This file should contain the ftp commands you would
use such as:

cd backup-folder
rm backup*
quit

#########################################################
"

echo -n "This script will copy:
	- all databases
	- all client/user directories (/home/www/html/USERS), these contain their:
		- websites
		- apache logs
		- awstats cache
		- various backups
	- webmail folder (squirrelmail, mailboy and any other webmail installed under /home/www/html/webmail)

By default the following direcories will also be saved as well
	- /etc
	- /home/vmail
	- /var/log
	- /usr/local/sbin
	- /var/cache/awstats

NOTE: If you need to modify this you may either:
 -> Enter here all directories to save (space separated values)
 -> Add or remove folders later on from /etc/diss/diss.conf (easy way out)

folders to be saved [default: /etc /home/vmail /var/log /usr/local/sbin /var/cache/awstats]: "
read BACKUPDIRS
: ${BACKUPDIRS:="/etc /home/vmail /var/log /usr/local/sbin /var/cache/awstats"}

echo -e "\nYou may configure an FTP server for DISS to upload the backup to. The uploaded backup will
by encrypted before the transfer.
If you prefer to manage the remote copy yourself simply respond N.

You may in any case indicate in a script to be executed once this local backup is complete:
	- BACKUPPOSTSCRIPT in /etc/diss/diss.conf\n"
echo -ne "\nDo you want to setup an FTP transfer via DISS script (y/N): "
read FTPYES
: ${FTPYES:="N"}
if [[ ${FTPYES} == [Yy] ]]; then
# FTP FIXME: ask for option to use ftp or not
	BACKUPFTP="Y"
	getInpute "FTP server we should use:" domain
	BACKUPFTPHOST="${ANSWER}"
	getInpute "FTP username:" user
	BACKUPFTPUSER="${ANSWER}"
	getInpute "FTP password:"
	BACKUPFTPPASS="${ANSWER}"
	getInpute "FTP backup directory:" dir
	BACKUPFTPDIR="${ANSWER}"
	echo -e "\nBefore sending the backup to the FTP server we should encrypt it.
	We'll make one image out of the daily backup, you should not
	consider data flowing over FTP as safe, and you might not
	trust the admin of the FTP server.
	For these reasons choose a password to encrypt the daily backup\n"
	getInpute "Encryption password: " pw
	BACKUPKEY="${ANSWER}"
	FTPMSG="\nFTP server to use: ${NCFTPBOOKMARK}
FTP username: ${BACKUPFTPUSER}
FTP password: ${BACKUPFTPPASS}
FTP backup folder: ${BACKUPFTPDIR}"
# END IF FTP
fi

echo -ne "\nWe shall create \"/home/backup\" and store the backup there,
if you want to use a different folder you may specify it here,
Enter full path [default: /home/backup]: "
read BACKUPROOT
: ${BACKUPROOT:="/home/backup"}

echo -ne "\nhow many days worth of backup do we want to keep (default 5): "
read BACKUPDAYS
: ${BACKUPDAYS:="5"}

# confirm stuff
echo -e "\n\nthe backup goes like this:

Folders to be backed up: ${BACKUPDIRS}
Local backupfolder: ${BACKUPROOT}
Conserve backups (days): ${BACKUPDAYS}
Backup key: ${BACKUPKEY} ${FTPMSG}

Please verify the above information"
confirmORdie

# create backup dir
mkdir ${BACKUPROOT}
chmod 700 ${BACKUPROOT}
chown root:root ${BACKUPROOT}

# actually start doing stuff
sed -i "s#BACKUPDIRS=#BACKUPDIRS=\"${BACKUPDIRS}\"#" /etc/diss/diss.conf
if [[ ${FTPYES} == [Yy] ]]; then
	sed -i "s/BACKUPFTP=/BACKUPFTP=\"${BACKUPFTP}\"/" /etc/diss/diss.conf
fi
sed -i "s/BACKUPFTPHOST=/BACKUPFTPHOST=\"${BACKUPFTPHOST}\"/" /etc/diss/diss.conf
sed -i "s/BACKUPFTPUSER=/BACKUPFTPUSER=\"${BACKUPFTPUSER}\"/" /etc/diss/diss.conf
sed -i "s/BACKUPFTPPASS=/BACKUPFTPPASS=\"${BACKUPFTPPASS}\"/" /etc/diss/diss.conf
sed -i "s#BACKUPFTPDIR=#BACKUPFTPDIR=\"${BACKUPFTPDIR}\"#" /etc/diss/diss.conf
sed -i "s/BACKUPDAYS=/BACKUPDAYS=\"${BACKUPDAYS}\"/" /etc/diss/diss.conf
sed -i "s/BACKUPKEY=/BACKUPKEY=\"${BACKUPKEY}\"/" /etc/diss/diss.conf
sed -i "s#BACKUPROOT=#BACKUPROOT=\"${BACKUPROOT}\"#" /etc/diss/diss.conf
echo "0 4 * * * root /usr/local/sbin/backup_diss.sh" >> /etc/crontab
ln -s /usr/local/${SOFTNAME}/sbin/backup_diss.sh /usr/local/sbin/

# mark as done
sed -i "s/BACKUPSTATE=\"not installed\"/BACKUPSTATE=\"done\"/" /etc/diss/diss.conf

echo "Backup configured.
It will run every morning at 4AM, to change that edit
the file /etc/crontab.
These folders will be backed up : ${BACKUPDIRS}

Edit /etc/diss/diss.conf at the line 'BACKUPDIRS' to add or remove directories.

Press enter to return to main menu"
read
exit
