#!/bin/bash

#   install_base.sh - install some basic crap like vim, and configure
#   a proper FQDN, stuff like that.
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

# FIXME
#	- IP: add some regex verifications
#	- reorganise to get data and then confirm before doing

clear
source /etc/diss/diss.conf
source ${SCRIPTS}/functions.sh

THISSCRIPT=install_base.sh
THISSTATE=${BASESTATE}
installStatus

#################
#	INPUTS		#
echo -ne "Welcome to blah blah diss\n\n"

# Detect OS (haha, I mean Debian version of course)
# is this really debian ?
if [[ -e "/etc/debian_version" ]]; then
	DEB_VERSION=`cat /etc/debian_version |cut -f 1 -d "."`
	if [[ $DEB_VERSION -eq 6 ]]; then
		DEB_ASL="squeeze"
		echo "Detected OS: Debian Squeeze"
	elif [[ $DEB_VERSION -lt 6 ]]; then
		DEB_ASL="lenny"
		echo "Detected OS: Debian Lenny"
	else
		# fail
		echo "Cannot determine debian version, this could be
		either bad version of debian, script or just a bug.
		I (script) am expecting a number like 6.0 or something.
		Press enter to quit (and dirty fix?)"
		read
		exit
	fi
else
	# fail
	echo "This does not look like a real Debian OS. If you
	want to fake it then add a number in /etc/debian_version that
	should correspond to the version of Debian you want to make
	DISS think you have"
fi

# reconfigure locales !
echo -ne "Do you want to reconfigure locales (Y/n):"
read LOCALES
: ${LOCALES:="Y"}

# confirm IP addr
FOUNDIP=`ifconfig |grep Bcast|cut -d ":" -f 2|cut -d " " -f 1`
DEFAULTIP=`ifconfig |grep Bcast|cut -d ":" -f 2|cut -d " " -f 1|head -n 1`
echo -e "#############\nFound IP(s) : ${FOUNDIP}\n#############\n\nVerify your IP and use the main IP here"
getInpute "Enter IP [default ${DEFAULTIP}]:" ip ${DEFAULTIP}
IP="${ANSWER}"

# Change FQDN ?
FQDN=`hostname --fqdn`
echo -ne "\nThis machine should have a proper hostname setup, something like: 'server.domain.tld'.\n
Ideally it should correspond to the PTR of the IP ${IP}
(or at least the PTR of the the public IP).\n
The current fully qualified domain name appears to be: -> ${FQDN} <-\n\nDo you wan't to change that (Y/n): "
read CHANGEFQDN
: ${CHANGEFQDN:="Y"}
if [[ ${CHANGEFQDN} == [Yy] ]]; then
	getInpute "Enter teh hostname (not FQDN) (ex: server001):" domain
	MACHINENAME="${ANSWER}"
	getInpute "Enter domain name (ex: domain.tld):" domain
	DOMAIN="${ANSWER}"
	FQDN="${MACHINENAME}.${DOMAIN}"
fi
#	End inputs	#
#################

#####################
#	CONFIRMATION	#
echo -ne "\nConfirm the following:\n - IP = ${IP}\n - FQDN = ${FQDN}\n - NOTE: we will attempt to apt upgrade\n\n"
confirmORdie
#	Confirmed		#
#####################

#################
#	DO STUFF	#

# reconfigure locales !
if [[ ${LOCALES} == [Yy] ]]; then
	dpkg-reconfigure locales
fi

# update before getting all crazy
apt-get update
apt-get upgrade -y
apt-get install -y screen vim bzip2 chrony nmap less openssh-client openssh-server

# vim config (and without even asking)
sed -i.diss-BKP -e 's/\"syntax on/syntax on/' -e 's/\"set background=dark/set background=dark/' /etc/vim/vimrc

# Change FQDN !
if [[ ${CHANGEFQDN} == [Yn] ]]; then
	dissBackupfile /etc/hosts
	dissBackupfile /etc/hostname
	echo ${MACHINENAME} > /etc/hostname
	hostname ${MACHINENAME}
	echo "127.0.0.1       localhost
127.0.1.1	${FQDN} ${MACHINENAME}
${IP}	${FQDN} ${MACHINENAME}

::1     ip6-localhost ip6-loopback
fe00::0 ip6-localnet
ff00::0 ip6-mcastprefix
ff02::1 ip6-allnodes
ff02::2 ip6-allrouters
ff02::3 ip6-allhosts"  > /etc/hosts
	echo -e "\n --> The Fully Qualified Domaine Name appears to be : `hostname --fqdn`"
	echo -e "\nnote: The files /etc/hostname and /etc/hosts have been rewritten,
there are backup copies (.diss-BKP) if you need to correct or
things personalize your configurations"
fi

# UPDATE DISS STATUS
sed -i "s/DEB_ASL=/DEB_ASL=\"${DEB_ASL}\"/" ${DISSETC}diss.conf
sed -i "s/BASESTATE=\"not installed\"/BASESTATE=\"done\"/" ${DISSETC}diss.conf
sed -i "s/IP=/IP=\"${IP}\"/" ${DISSETC}diss.conf
sed -i "s/FQDN=/FQDN=\"${FQDN}\"/" ${DISSETC}diss.conf

echo -e "\n --> Base install done\n
press any key to return to DISS menu\n"
read
# Done
####################
exit
