#!/bin/bash

#   install_lamp.sh - Install a LAMP server
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

# FIXME:
#	D - permission to use awstats.pl - with direct link no htaccess is required !
#	  actually just need to further test, maybe as well on users nimda spaces
#	D - check if user exists (use previous value for user creation to modify or not proftpd.conf)
#	T - check if apache logs get rotated and deleted
#	D - add ftp tls/ssl
#	D - check mysql user creation for admin user

clear
source /etc/diss/diss.conf
source ${SCRIPTS}/functions.sh

THISSCRIPT=install_lamp.sh
THISSTATE=${WEBSTATE}
# test if this has already been done :
installStatus

# test if install_base has been done, if not show a message
DEPENDSTATE=${BASESTATE}
DEPENDSON="install_base"
dependsOn

#################
#	INPUTS		#
echo -e "\n
#########################################
#					#
#	Web server installation		#
#					#
#########################################\n
This script will install:
 - Apache
 - Mysql
 - PHP5
 - Proftpd
 - Awstats
 - Munin
 - PhpSysinfo\n
Press enter to continue  =>\n"
read

# set mysql root pass
getInpute "Set mysql *ROOT* password:" pw
SQLPASS="${ANSWER}"

# get username, main domain, admin subdomain and pass
echo -e "\nThis user will also be the main admin user"
getInpute "Enter user/client login:" user
CLIENT="${ANSWER}"

# default domain and alias
getInpute "Enter main/default domain/site name (ex domain.tld):" domain
DOMAIN="${ANSWER}"
testDomain ${DOMAIN}
echo -n "Enter subdomain or alias (e.g. www.domain.tld or otherdomain.tld) OPTIONAL: "
read -e ALIAS
test ${ALIAS} || ALIAS="--None--"
if [ "${ALIAS}" != "--None--" ]; then
	testDomain ${ALIAS}
fi

# admin vhost
echo -e "\nWe will create a subdomain for accessing Phpmyadmin, Awstats and system information."
getInpute "Subdomain (for https://private.${DOMAIN} enter \"private\"):" domain
NIMDA="${ANSWER}"
testDomain ${NIMDA}.${DOMAIN}

getInpute "Password for ${CLIENT} (will be used for FTP, MySQL and web https://${NIMDA}.${DOMAIN}):" pw
CLIENTPASS="${ANSWER}"
#	End inputs	#
#################

#####################
#	CONFIRMATION	#
echo -e "confirm the following before proceeding :\n
 main account name : ${CLIENT}
 main site : ${DOMAIN}
 alias : ${ALIAS}
 sub domain for administration : ${NIMDA}.${DOMAIN}
 password : ${CLIENTPASS}
 root MySQL password : ${SQLPASS}\n
Double check the information above"
# confirm before actually doing anything
confirmORdie
#	Confirmed		#
#####################


#################
#	MAIN USER	#
# test user/client
# TODO do more tests (-/etc/diss/clients/)
test -d /home/www/html/${CLIENT} || NEW=1
if [ "$NEW" = "1" ]; then
	echo " => the user doesn't exist in DISS (good news)"
else
	echo " => the client already exists. .. .  must die()
	(check your configuration and reload script)"
	read
	exit
fi
# test if the user already exists on the system
egrep "^${CLIENT}" /etc/passwd >/dev/null
	if [ $? -eq 0 ]; then
		echo -e " => the user ${CLIENT} exists, we shall not recreate it NOR modify\nthe system password (used by FTP)."
		CREATEUSER=0
	else
		echo " => the user ${CLIENT} does not exist .. . . .. YET :]"
		CREATEUSER=1
		CLIENTNIXPASS=$(perl -e 'print crypt($ARGV[0], "password")' ${CLIENTPASS})
		useradd --shell /bin/false -p ${CLIENTNIXPASS} ${CLIENT} -d /home/www/html/${CLIENT}
fi
# create usful directories - with awstats cache AND apache logs in users home
mkdir -p /home/www/html/${CLIENT}/${DOMAIN}
mkdir -p /home/www/html/${CLIENT}/system/awstats/${DOMAIN}
mkdir -p /home/www/html/${CLIENT}/system/apache_logs/
#	NIMDA SPACE
mkdir -p /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/clients
mkdir -p /home/www/html/${CLIENT}/system/awstats/${NIMDA}.${DOMAIN}
# copy files to the admin area
cp /usr/local/${SOFTNAME}/nimda/index_nimda_global.php /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/index.php
cp -r /usr/local/${SOFTNAME}/nimda/style/ /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/
cp /usr/local/${SOFTNAME}/nimda/favicon.ico /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/
# create links in admin page
echo -e "<h3>Main account:  ${CLIENT}</h3>
<ul>
	<li><a href=\"/awstats/awstats.pl?config=${DOMAIN}\">${DOMAIN}</a></li>
	<li><a href=\"/awstats/awstats.pl?config=${NIMDA}.${DOMAIN}\">${NIMDA}.${DOMAIN}</a></li>\n" > /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/links.html
# set permissions
chown -R root:www-data /home/www/html/${CLIENT}
chown ${CLIENT}:www-data /home/www/html/${CLIENT}/${DOMAIN}
chown ${CLIENT}:www-data /home/www/html/${CLIENT}/system
chmod 750 /home/www/html/${CLIENT}/system
chmod 750 /home/www/html/${CLIENT}/${DOMAIN}
chmod 750 /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
CLIENTPATH="/home/www/html/${CLIENT}"
mkBackupDir
#	MAIN USER 	#
#################

#################
#	APT-GET *	#
DEBIAN_PRIORITY=critical apt-get install -y mysql-server phpmyadmin proftpd hddtemp
aptitude install -y lha unrar openssl apache2 apache2-suexec libapache2-mod-php5 php5-mysql telnet php-pear php5-cli \
php5-curl php5 libapache2-mod-fcgid php5-cgi lftp ncftp munin munin-node phpsysinfo lm-sensors awstats
#	APT-GOT		#
#################

#############
#	MYSQL	#
# set the MYSQL root passwd
mysqladmin password ${SQLPASS}
# create normal sql user (client)
mysql -uroot -p${SQLPASS} -e "CREATE USER '${CLIENT}'@'localhost' IDENTIFIED BY '${CLIENTPASS}'; GRANT USAGE ON * . * TO '${CLIENT}'@'localhost' IDENTIFIED BY '${CLIENTPASS}' WITH MAX_QUERIES_PER_HOUR 0 MAX_CONNECTIONS_PER_HOUR 0 MAX_UPDATES_PER_HOUR 0 MAX_USER_CONNECTIONS 0 ; GRANT ALL PRIVILEGES ON \`${CLIENT}\_%\` . * TO '${CLIENT}'@'localhost';"
#	MYSQL	#
#############

#############
#	PHP		#
dissBackupfile /etc/php5/apache2/php.ini
dissBackupfile /etc/php5/cgi/php.ini
cp ${DEFCONFS}/php/php.ini /etc/php5/apache2/php.ini
cp ${DEFCONFS}/php/php_cgi.ini /etc/php5/cgi/php.ini

# create /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter
mkdir -p /var/www/php-fcgi-scripts/${CLIENT}
echo "#!/bin/bash
PHPRC=/etc/php5/cgi/
export PHPRC
export PHP_FCGI_MAX_REQUESTS=5000
export PHP_FCGI_CHILDREN=2
exec /usr/lib/cgi-bin/php" > /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter
chown -R ${CLIENT}:${CLIENT} /var/www/php-fcgi-scripts/${CLIENT}/
chmod 755 /var/www/php-fcgi-scripts/${CLIENT}/
chmod +x /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter
#	PHP		#
#############

##############
# PHPMYADMIN #
dissBackupfile /etc/phpmyadmin/apache.conf
echo "Alias /phashp \"/usr/share/phpmyadmin\"
<Directory /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/phashp>
	Options FollowSymLinks MultiViews
	AllowOverride None
	Order allow,deny
	allow from all
</Directory>" > /etc/phpmyadmin/apache.conf
# PHPMYADMIN #
##############

#############################
#	MUNIN (+phpysysinfo)	#
dissBackupfile /etc/munin/munin.conf
sed -i "s/localhost.localdomain/${FQDN}/" /etc/munin/munin.conf
if [[ $DEB_ASL == "squeeze" ]]; then
	# remove sylink that will alias /munin on all of apache !
	rm /etc/apache2/conf.d/munin
	MUNINDIR="/var/cache/munin/www"
else
	MUNINDIR="/var/www/munin"
fi
echo "Alias /munin ${MUNINDIR}
<Directory ${MUNINDIR}>
	<IfModule mod_expires.c>
		ExpiresActive On
		ExpiresDefault M310
	</IfModule>
</Directory>" > /etc/munin/apache-diss.conf
/etc/init.d/munin-node restart
#	MUNIN (+phpysysinfo)	#
#############################

#####################
#	APACHE CONFIG	#
# create HTPASSWD
htpasswd -cmb /home/www/.htpasswd ${CLIENT} ${CLIENTPASS}
chown root:www-data /home/www/.htpasswd
chmod 640 /home/www/.htpasswd

# SSL certificate
clear
echo -ne "\nWe shall make an Apache certificate for accessing
\t -> https://${NIMDA}.${DOMAIN}\n
to avoid \"domain mismatch\" errors make sure to answer: ${NIMDA}.${DOMAIN}
for the \"common name\"\n\npress enter when ready"
read
openssl req $@ -new -x509 -days 730 -nodes -out /etc/apache2/apache.pem -keyout /etc/apache2/apache.pem
chmod 600 /etc/apache2/apache.pem
echo "NameVirtualHost *:443" >> /etc/apache2/ports.conf
a2enmod ssl

# APACHE MODULES
cp ${DEFCONFS}/apache/deflate.conf /etc/apache2/mods-available/
cp ${DEFCONFS}/apache/expires.conf /etc/apache2/mods-available/
cp ${DEFCONFS}/apache/headers.conf /etc/apache2/mods-available/
dissBackupfile /etc/apache2/mods-available/php5.conf
cp ${DEFCONFS}/apache/php5.conf /etc/apache2/mods-available/
a2enmod cache
a2enmod mem_cache
a2enmod rewrite
a2enmod suexec
a2enmod include
a2enmod fcgid
a2enmod php5
a2enmod headers
a2enmod deflate
a2enmod expires
sed -i "s/FcgidConnectTimeout 20/\tFcgidConnectTimeout 20\n\tMaxRequestLen 15728640/" /etc/apache2/mods-available/fcgid.conf

# APACHE LOGROTATE
echo "/home/www/html/*/system/apache_logs/*.log {
    weekly
    missingok
    rotate 52
    compress
    delaycompress
    notifempty
    create 640 root adm
    sharedscripts
    postrotate
        if [ -f \"\`. /etc/apache2/envvars ; echo \${APACHE_PID_FILE:-/var/run/apache2.pid}\`\" ]; then
            /etc/init.d/apache2 reload > /dev/null
        fi
    endscript
}" >> /etc/logrotate.d/apache2

# APACHE CONFIGURATION
sed -i "s/ServerTokens OS/ServerTokens Prod/" /etc/apache2/conf.d/security
sed -i "s/ServerSignature On/ServerSignature Off/" /etc/apache2/conf.d/security
echo "Options -Indexes" >> /etc/apache2/httpd.conf
# make webspace for default vhost
mkdir -p /home/www/html/default
cp -r ${DEFCONFS}/apache/default-www/* /home/www/html/default/

echo 'Alias /awstatsicons "/usr/share/awstats/icon/"
Alias /awstatscss "/usr/share/doc/awstats/examples/css"
Alias /awstatsclasses "/usr/share/awstats/lib/"
ScriptAlias /awstats/awstats.pl "/usr/lib/cgi-bin/awstats.pl"
<Files "awstats.pl">
	AuthUserFile /home/www/.htpasswd
	AuthGroupFile /dev/null
	AuthName "Please your enter credentials"
	AuthType Basic
	require valid-user
</Files>' > /etc/apache2/awstats.conf

# APACHE CLIENT NIMDA VHOST
if [[ $DEB_ASL == "squeeze" ]]; then
	PHPSYSINFOALIAS="Alias /phpsysinfo \"/usr/share/phpsysinfo/\""
else
	PHPSYSINFOALIAS="Alias /phpsysinfo \"/var/www/phpsysinfo\""
fi
echo "<VirtualHost *:443>
	SSLEngine on
	SSLCertificateFile /etc/apache2/apache.pem

	ServerName ${NIMDA}.${DOMAIN}
	DocumentRoot /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
	CustomLog /home/www/html/${CLIENT}/system/apache_logs/${NIMDA}.${DOMAIN}.log combined
	CustomLog /var/log/apache2/global.log combined

	<Location />
		AuthUserFile /home/www/.htpasswd
		AuthName \"Enter Credentials\"
		AuthType Basic
		<Limit GET POST>
			Require user ${CLIENT}
		</Limit>
	</Location>

	<Directory /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}>
		AllowOverride AuthConfig
		Options FollowSymLinks MultiViews
		Order allow,deny
		allow from all
	</Directory>

	${PHPSYSINFOALIAS}
	Include	/etc/phpmyadmin/apache.conf
	Include /etc/munin/apache-diss.conf
	Include awstats.conf

</VirtualHost>" > /etc/apache2/sites-available/${CLIENT}_${NIMDA}.${DOMAIN}

# APACHE CLIENT NORMAL VHOST
if [ "${ALIAS}" = "--None--" ]; then
        echo "<VirtualHost *:80>
	ServerName ${DOMAIN}
	DocumentRoot /home/www/html/${CLIENT}/${DOMAIN}
	SuexecUserGroup ${CLIENT} ${CLIENT}
	<Directory /home/www/html/${CLIENT}/${DOMAIN}>
		Options +ExecCGI
		AllowOverride All
		AddHandler fcgid-script .php
		FCGIWrapper /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter .php
		Order allow,deny
		Allow from all
	</Directory>
	CustomLog /home/www/html/${CLIENT}/system/apache_logs/${DOMAIN}.log combined
	CustomLog /var/log/apache2/global.log combined
</VirtualHost>" > /etc/apache2/sites-available/${CLIENT}_${DOMAIN}
else
	echo "<VirtualHost *:80>
	ServerName ${DOMAIN}
	ServerAlias ${ALIAS}
	DocumentRoot /home/www/html/${CLIENT}/${DOMAIN}
	SuexecUserGroup ${CLIENT} ${CLIENT}
	<Directory /home/www/html/${CLIENT}/${DOMAIN}>
		Options +ExecCGI
		AllowOverride All
		AddHandler fcgid-script .php
		FCGIWrapper /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter .php
		Order allow,deny
		Allow from all
	</Directory>
	CustomLog /home/www/html/${CLIENT}/system/apache_logs/${DOMAIN}.log combined
	CustomLog /var/log/apache2/global.log combined
</VirtualHost>" > /etc/apache2/sites-available/${CLIENT}_${DOMAIN}
fi

# APACHE DEFAULT WEBSPACE (access by IP)
echo "<VirtualHost *:80>
	ServerName *
	DocumentRoot /home/www/html/default/
	CustomLog /var/log/apache2/global.log combined
</VirtualHost>

<VirtualHost *:443>
	ServerName *
	SSLEngine on
	SSLCertificateFile /etc/apache2/apache.pem
	DocumentRoot /home/www/html/default/
	CustomLog /var/log/apache2/global.log combined
</VirtualHost>" > /etc/apache2/sites-available/default

# APACHE HTACCESS
#echo "
#" > /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/.htaccess
#chown root:www-data /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/.htaccess
#chmod 640 /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/.htaccess

a2ensite ${CLIENT}_${NIMDA}.${DOMAIN}
a2ensite ${CLIENT}_${DOMAIN}
/etc/init.d/apache2 restart
#	APACHE DONE		#
#####################

#################
#	PROFTPD		#
dissBackupfile /etc/proftpd/proftpd.conf
# add FQDN to ftp banner
sed "s/replacedbyscript/${FQDN}/" < ${DEFCONFS}/proftpd.conf > /etc/proftpd/proftpd.conf
# if main client/user already exists he will be badly ftprooted, so we add something
if [ "${CREATEUSER}" == "0" ]; then
	sed -i "s#DefaultRoot ~#DefaultRoot /home/www/html/${CLIENT} ${CLIENT}#" /etc/proftpd/proftpd.conf
	echo "DefaultRoot ~" >> /etc/proftpd/proftpd.conf
fi
# add TLS/SSL certificate
mkdir /etc/proftpd/ssl
echo -e "\n=> Creating SSL certificate for PROFTPD\n\n -> Press enter to proceed"
read
openssl req -new -x509 -days 365 -nodes -out /etc/proftpd/ssl/proftpd.cert.pem -keyout /etc/proftpd/ssl/proftpd.key.pem
/etc/init.d/proftpd restart
#	PROFTPD		#
#################

#################
#	AWSTATS		#
if [ ! -d /var/cache/awstats ]; then
	mkdir /var/cache/awstats
fi
chown www-data:www-data /var/cache/awstats
mkdir /etc/awstats/diss-BKP/
mv /etc/awstats/awstats* /etc/awstats/diss-BKP/
cp ${DEFCONFS}/awstats/awstats.ftp.conf /etc/awstats/
cp ${DEFCONFS}/awstats/include.conf /etc/awstats/
cp ${DEFCONFS}/awstats/diss-logo_awstats.png /usr/share/awstats/icon/other/

# make web stats for ftp server usage
sed -i "s/SiteDomain=/SiteDomain=\"ftp.${DOMAIN}\"/" /etc/awstats/awstats.ftp.conf
sed -i "s/AllowAccessFromWebToFollowingAuthenticatedUsers=/AllowAccessFromWebToFollowingAuthenticatedUsers=\"${ADMINUSER}\"/" /etc/awstats/awstats.ftp.conf

# links awstats update script to /usr/local/sbin + cron it
ln -s /usr/local/diss/sbin/awstats-cronbin.sh /usr/local/sbin/
chmod +x /usr/local/sbin/awstats-cronbin.sh
echo "0 6,12,18,22 * * * root /usr/local/sbin/awstats-cronbin.sh &> /dev/null" >> /etc/crontab

# create conf files for domain, admin domain and global stats
echo  "LogFile=\"/home/www/html/${CLIENT}/system/apache_logs/${NIMDA}.${DOMAIN}.log\"
SiteDomain=\"${NIMDA}.${DOMAIN}\"
AllowAccessFromWebToAuthenticatedUsersOnly=1
AllowAccessFromWebToFollowingAuthenticatedUsers=\"${CLIENT}\"
DefaultFile=\"index.html\"
ShowFlagLinks=\"en de fr\"
Lang=\"en\"
DirData=\"/home/www/html/${CLIENT}/system/awstats/${NIMDA}.${DOMAIN}\"
Include \"include.conf\"" > /etc/awstats/awstats.${NIMDA}.${DOMAIN}.conf

if [ "${ALIAS}" = "--None--" ]; then
	echo  "LogFile=\"/home/www/html/${CLIENT}/system/apache_logs/${DOMAIN}.log\"
SiteDomain=\"${DOMAIN}\"
AllowAccessFromWebToAuthenticatedUsersOnly=1
AllowAccessFromWebToFollowingAuthenticatedUsers=\"${CLIENT}\"
DefaultFile=\"index.html\"
ShowFlagLinks=\"en de fr\"
Lang=\"en\"
DirData=\"/home/www/html/${CLIENT}/system/awstats/${DOMAIN}\"
Include \"include.conf\"" > /etc/awstats/awstats.${DOMAIN}.conf
else
	echo  "LogFile=\"/home/www/html/${CLIENT}/system/apache_logs/${DOMAIN}.log\"
SiteDomain=\"${DOMAIN}\"
HostAliases=\"${ALIAS}\"
AllowAccessFromWebToAuthenticatedUsersOnly=1
AllowAccessFromWebToFollowingAuthenticatedUsers=\"${CLIENT}\"
DefaultFile=\"index.html\"
ShowFlagLinks=\"en de fr\"
Lang=\"en\"
DirData=\"/home/www/html/${CLIENT}/system/awstats/${DOMAIN}\"
Include \"include.conf\"" > /etc/awstats/awstats.${DOMAIN}.conf
fi

echo  "LogFile=\"/var/log/apache2/global.log\"
SiteDomain=\"global\"
AllowAccessFromWebToAuthenticatedUsersOnly=1
AllowAccessFromWebToFollowingAuthenticatedUsers=\"${CLIENT}\"
DefaultFile=\"index.html\"
ShowFlagLinks=\"en de fr\"
Lang=\"en\"
DirData=\"/var/cache/awstats\"
Include \"include.conf\"" > /etc/awstats/awstats.global.conf
#	AWSTATS		#
#################

#####################
#	DISS CONFIG		#
# UPDATE DISS STATUS
sed -i "s/ADMINUSER=/ADMINUSER=\"${CLIENT}\"/" ${DISSETC}/diss.conf
sed -i "s/ADMINSITE=/ADMINSITE=\"${DOMAIN}\"/" ${DISSETC}/diss.conf
sed -i "s/ADMINNIMDA=/ADMINNIMDA=\"${NIMDA}\"/" ${DISSETC}/diss.conf
sed -i "s/ADMINNIMDAURL=/ADMINNIMDAURL=\"${NIMDA}.${DOMAIN}\"/" ${DISSETC}/diss.conf
sed -i "s/ADMINPATH=/ADMINPATH=\"\/home\/www\/html\/${CLIENT}\"/" ${DISSETC}/diss.conf
sed -i "s/ADMINNIMDAPATH=/ADMINNIMDAPATH=\"\/home\/www\/html\/${CLIENT}\/${NIMDA}.${DOMAIN}\"/" ${DISSETC}/diss.conf
sed -i "s/ROOTSQL=/ROOTSQL=\"${SQLPASS}\"/" ${DISSETC}/diss.conf

if [ "${ALIAS}" != "--None--" ]; then
	CLIENTDOMAIN="${DOMAIN} ${ALIAS}"
else
	CLIENTDOMAIN="${DOMAIN}"
fi
# DISS client config file
# first client so
mkdir /etc/${SOFTNAME}/clients
chmod 700 /etc/${SOFTNAME}/clients
echo "#!/bin/bash

# DISS config file for: ${CLIENT}

CLIENT=${CLIENT}
CLIENTSITE=${DOMAIN}
CLIENTNIMDA=${NIMDA}
CLIENTNIMDAURL=\"\${CLIENTNIMDA}.\${CLIENTSITE}\"
CLIENTPATH=\"${CLIENTPATH}\"
CLIENTNIMDAPATH=\"\${CLIENTPATH}/\${CLIENTNIMDAURL}\"
CLIENTPASS=\"${CLIENTPASS}\"
CLIENTDOMAIN[1]=\"${CLIENTDOMAIN}\""  > /etc/${SOFTNAME}/clients/${CLIENT}.conf
chmod 600 /etc/${SOFTNAME}/clients/${CLIENT}.conf
# update install status in diss.conf and open required ports
sed -i "s/WEBSTATE=\"not installed\"/WEBSTATE=\"done\"/" ${DISSETC}/diss.conf
# firewall stuff - add new ports to diss.conf and restart firewall it is installed
NEWTCPPORTS="${ARNO_OPEN_TCP} 21 80 443 50000:51000"
sed -i "s/ARNO_OPEN_TCP=\"${ARNO_OPEN_TCP}\"/ARNO_OPEN_TCP=\"${NEWTCPPORTS}\"/" ${DISSETC}/diss.conf
echo -e "\nDISS: updating open ports (${NEWTCPPORTS}) in firewall config"
if [ -a "/etc/arno-iptables-firewall/debconf.cfg" ]; then
	source /etc/arno-iptables-firewall/debconf.cfg
	sed -i "s/DC_OPEN_TCP=\"${DC_OPEN_TCP}\"/DC_OPEN_TCP=\"${NEWTCPPORTS}\"/" /etc/arno-iptables-firewall/debconf.cfg
	/etc/init.d/arno-iptables-firewall restart
fi
#	DISS CONFIG		#
#####################

echo -ne "\nEnd of installation, we made it !!\n
press enter to get a print out of what you need to remember <--"
read
clear

echo "

########################
#                      #
#	INFOS	       #
#                      #
########################

WEB/FTP
- Main user account (FTP): ${CLIENT}
- Password for user ${CLIENT}: ${CLIENTPASS}
- Configured Web space for: ${DOMAIN}
- Absolute path: /home/www/html/${CLIENT}/${DOMAIN}

DB/PhpMyadmin
- Root MySQL user is: root
- Password for MySQL user 'root': ${SQLPASS}

DNS stuff
- Server's IP is: ${IP}
- DNS (Bind) configuration should look something like:
        ${NIMDA}.${DOMAIN} 3600 IN A ${IP}
        ${DOMAIN} 3600 IN A ${IP}" > /etc/diss/infos_lamp
if [ "${ALIAS}" != "--None--" ]; then
        echo "	${ALIAS}  3600 IN A  ${IP}" >> /etc/diss/infos_lamp
fi

echo "
- A bit more simple (depends on how you manage your DNS):
        ${NIMDA}.${DOMAIN}  A  ${IP}
        ${DOMAIN}  A  ${IP}" >> /etc/diss/infos_lamp
if [ "${ALIAS}" != "--None--" ]; then
        echo "	${ALIAS}  A  ${IP}" >> /etc/diss/infos_lamp
fi

echo "
Administration and misc:
- To manage and view PhpMyadmin and Awstats:
	https://${NIMDA}.${DOMAIN}
	User: ${CLIENT}
	Password: ${CLIENTPASS}

- The FTP account should arrive directly in /home/www/html/${CLIENT}" >> /etc/diss/infos_lamp
chmod 600 /etc/diss/infos_lamp
echo -ne "`cat /etc/diss/infos_lamp`

press \"Enter\" to go back to the main menu"
read
exit
