#!/bin/bash

#   reconfigure_firewall.sh - add new ports to diss.conf and restart firewall
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

clear
source /etc/diss/diss.conf
source ${SCRIPTS}/functions.sh

# has the firewall been installed ?
DEPENDSTATE=${FIREWALLSTATE}
DEPENDSON="install_firewall"
dependsOn

# Get Answers by whipping
NEWTCPPORTS=`whiptail --nocancel --title "DISS v.${VERSION}" --inputbox "Open TCP Ports\nSpecify a port range with a colon\nexample: 6000:6100" 10 55 "${ARNO_OPEN_TCP}" 3>&2 2>&1 >&3`
NEWUDPPORTS=`whiptail --nocancel --title "DISS v.${VERSION}" --inputbox "Open UDP Ports\nSpecify a port range with a colon\nexample: 6000:6100" 10 55 "${ARNO_OPEN_UDP}" 3>&2 2>&1 >&3`
OPENPING=`whiptail --nocancel --title "DISS v.${VERSION}" --inputbox "Allow Ping (1=yes 0=no)" 10 35 "${ARNO_OPEN_ICMP}" 3>&2 2>&1 >&3`

clear
echo "

This is the new firewall configuration:

#####
Open TCP: ${NEWTCPPORTS}
Open UDP ${NEWUDPPORTS}
Allow Ping: ${OPENPING} (0=not 1=yes)
#####"

confirmORdie

# Update DISS config
sed -i "s/ARNO_OPEN_TCP=\"${ARNO_OPEN_TCP}\"/ARNO_OPEN_TCP=\"${NEWTCPPORTS}\"/" ${DISSETC}/diss.conf
sed -i "s/ARNO_OPEN_UDP=\"${ARNO_OPEN_UDP}\"/ARNO_OPEN_UDP=\"${NEWUDPPORTS}\"/" ${DISSETC}/diss.conf
#sed -i "s/ARNO_OPEN_ICMP=\"${ARNO_OPEN_ICMP}\"/ARNO_OPEN_ICMP=\"${OPENPING}\"/" ${DISSETC}/diss.conf
sed -i "s/\(^ARNO_OPEN_ICMP=\)\(.*$\)/ARNO_OPEN_ICMP=\"${OPENPING}\"/" ${DISSETC}/diss.conf

# Update Debconf/Arno config
source /etc/arno-iptables-firewall/debconf.cfg
sed -i "s/DC_OPEN_TCP=\"${DC_OPEN_TCP}\"/DC_OPEN_TCP=\"${NEWTCPPORTS}\"/" /etc/arno-iptables-firewall/debconf.cfg
sed -i "s/DC_OPEN_UDP=\"${DC_OPEN_UDP}\"/DC_OPEN_UDP=\"${NEWUDPPORTS}\"/" /etc/arno-iptables-firewall/debconf.cfg
#sed -i "s/DC_OPEN_ICMP=\"${DC_OPEN_ICMP}\"/DC_OPEN_ICMP=\"${OPENPING}\"/" /etc/arno-iptables-firewall/debconf.cfg
sed -i "s/\(^DC_OPEN_ICMP=\)\(.*$\)/DC_OPEN_ICMP=\"${OPENPING}\"/" /etc/arno-iptables-firewall/debconf.cfg

# Restart the firewall
/etc/init.d/arno-iptables-firewall restart

echo "Configuration updated

Press enter to go back to DISS menu"
read

exit
